var restify = require('restify');
var tesseractjs = require('tesseract.js')
var jc = require('json-cycle');
var parseOcr = require('./parseOcr')
const path = require("path");
const imageProcessing = require('./imageProcessing')

const tesseract = tesseractjs.create({
  workerPath: path.join(__dirname, '../../tesseract/src/node/worker.js'),
  langPath: path.join(__dirname, '../../tesseract/langs/'),
  corePath: path.join(__dirname, '../../tesseract/src/index.js')
})

const server = restify.createServer({
  name: 'ReceiptGuruAPI',
  version: '1.0.0'
});

server.use(restify.plugins.acceptParser(server.acceptable));
server.use(restify.plugins.queryParser());
server.use(restify.plugins.bodyParser());

server.get('rest/echo/:name', function (req, res, next) {
  res.send(req.params);
  return next();
});

const DUMMY_RESP = false;

server.post('rest/parseReceipt', function (req, res, next) {
  //Get the file somehow
  if(DUMMY_RESP){
    res.send({
        items: [
          {
            name: 'name1',
            price: 0.1,
            order: 1
          },
          {
            name: 'name2',
            price: 0.2,
            order: 2
          },
          {
            name: 'nameN',
            price: 0.3,
            order: 3
          }
        ]
       })
    return next()
  }
  console.log(req.body)
  var openedImage = imageProcessing.openImage(req.body)
  tesseract.recognize(openedImage, {
    lang: 'eng',
    tessedit_char_whitelist: 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890()*<>$.@/',
    user_words_file: path.join(__dirname, 'receipt.words'),
    user_patterns_file: path.join(__dirname, 'receipt.user-patterns')
  }).then(function(result){

    //this needs cut down heavily so that the response is cleaner
    //ideal is cutting it down to the lines, with words and like top 3 choices for each imo
    var cutRes = {}
    cutRes.lines = []
    console.log(result.paragraphs[0].text)
    for (let line of result.lines){
      var newLine = {}
      newLine.text = line.text
      newLine.words = []
      for (let word of line.words) {
        var newWord = {}
        newWord.text = word.text
        //add choices after
        newWord.choices = word.choices.slice(0,3)
        newWord.confidence = word.confidence
        console.log(newWord)
        newLine.words.push(newWord)
      }
      cutRes.lines.push(newLine)
    }
    var jsonFixed = jc.decycle(cutRes.lines)
    var receipt = parseOcr.cleanReceipt(jsonFixed)

    res.send(receipt)
})
  //JPEG/PNG Decoder
  //Tesseract
  //Return
  //
  console.log('ready to process next')
  return next()
})


server.post('rest/parseReceipt/full', function (req, res, next) {
  //Get the file somehow
  console.log(req.body)
  var openedImage = imageProcessing.openImage(req.body)
  tesseract.recognize(openedImage, {
    lang: 'eng',
    tessedit_char_whitelist: 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890()*<>$.@/',
    user_words_file: path.join(__dirname, 'receipt.words'),
    user_patterns_file: path.join(__dirname, 'receipt.user-patterns')
  }).then(function(result){

    var jsonFixed = jc.decycle(result)
    res.send(jsonFixed)
})
  //JPEG/PNG Decoder
  //Tesseract
  //Return
  //
  console.log('ready to process next')
  return next()
})


server.listen(8081, function () {
  console.log('%s listening at %s', server.name, server.url);
});
