
import { shallow } from '@vue/test-utils'
import App from '@/App'

const wrapperFactory = () => {
  return shallow(App, {
    stubs:['router-link', 'router-view'],
    attachToDocument: true
  })
}

describe('App.vue', () => {
  it('should render correct contents', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.contains('.navbar')).toEqual(true)
  })
  it('should know that new users are not returning', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.vm.isReturning()).toBe(false)
  })
  it('should know that returning users are returning', () => {
    const wrapper = wrapperFactory()
    wrapper.vm.setReturning(true)
    expect(wrapper.vm.isReturning()).toBe(true)
  })
  it('should recognize that a user has completed the tutorial', () => {
    const wrapper = wrapperFactory()
    wrapper.find('.rg-done').trigger('click')
    expect(wrapper.vm.isReturning()).toBe(true)
  })
  it('should allow a user to repeat the tutorial', () => {
    const wrapper = wrapperFactory()
    wrapper.vm.setReturning(true)
    wrapper.find('.rg-redo').trigger('click')
    expect(wrapper.vm.isReturning()).toBe(false)
  })
  it('should hide and show the navbar on mobile', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.vm.collapse).toBe(true)
    wrapper.find('.navbar-toggle').trigger('click')
    expect(wrapper.vm.collapse).toBe(false)
    wrapper.find('.navbar-toggle').trigger('click')
    expect(wrapper.vm.collapse).toBe(true)
  })
})

