
import { shallow } from '@vue/test-utils'
import Review from '@/components/Review'
import Vue from 'vue'
import Receipt from '@/receipt'

const wrapperFactory = () => {
  const r = new Receipt(
    'foo',
    [
      {name:'bar', price:1, category:'1', order:1},
      {name:'bar2', price:2, category:'2', order:2}
    ]
  )
  r.commitTo(Vue.localStorage)
  const $route = {params: {receipt_id: 'foo'}}
  const $router = {push: jest.fn()}
  return shallow(Review, {
    attachToDocument: true,
    mocks: {
      $route,
      $router
    }
  })
}

describe('Review.vue', () => {
  it('should render correct contents', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.findAll('.rg-review-table tbody tr').length).toBe(2)
    expect(wrapper.find('.rg-add').isVisible()).toBe(true)
    expect(wrapper.find('.rg-reject').isVisible()).toBe(true)
    expect(wrapper.find('.rg-confirm').isVisible()).toBe(true)
  })
  it('should remove receipt on remove', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.findAll('.rg-review-table tbody tr').length).toBe(2)
    wrapper.find('.rg-remove').trigger('click')
    expect(wrapper.findAll('.rg-review-table tbody tr').length).toBe(1)
  })
  it('should add and edit receipt on add', () => {
    const wrapper = wrapperFactory()
    expect(wrapper.findAll('.rg-review-table tbody tr').length).toBe(2)
    wrapper.find('.rg-add').trigger('click')
    expect(wrapper.find('.rg-modal').isVisible()).toBe(true)
    wrapper.find('.rg-modal form').trigger('submit')
    expect(wrapper.findAll('.rg-review-table tbody tr').length).toBe(3)
  })
  it('should try to retake on reject', () => {
    const wrapper = wrapperFactory()
    wrapper.find('.rg-reject').trigger('click')
    expect(wrapper.vm.$router.push.mock.calls[0]).toEqual([{name: 'TakePhoto'}])
  })
  it('should go to overview on accept', () => {
    const wrapper = wrapperFactory()
    wrapper.find('.rg-confirm').trigger('click')
    expect(wrapper.vm.$router.push.mock.calls[0]).toEqual([{name: 'MyReceipts'}])
  })
  it('should display edit modal when editing a receipt', () => {
    const wrapper = wrapperFactory()
    wrapper.find('.rg-edit').trigger('click')
    expect(wrapper.find('.rg-modal').isVisible()).toBe(true)
    wrapper.find('.rg-modal form').trigger('submit')
    expect(wrapper.vm.editing).toBe(false)
  })
  it('should select and deselect rows', () =>{
    const wrapper = wrapperFactory()
    expect(wrapper.vm.selectedRows).toEqual([])
    wrapper.find('.rg-review-table tbody tr').trigger('click')
    expect(wrapper.vm.selectedRows[0]).toEqual({name:'bar', price:1, category:'1', order:1})
    wrapper.find('.rg-review-table tbody tr').trigger('click')
    expect(wrapper.vm.selectedRows).toEqual([])
  })
  it('should categorize items',  () => {
    const wrapper = wrapperFactory()
    wrapper.find('.rg-review-table tbody tr').trigger('click')
    expect(wrapper.vm.receipt.items[0].category).toEqual('1')
    wrapper.vm.paintRows({title: 'foo'})
    expect(wrapper.vm.receipt.items[0].category).toEqual('foo')

  })
})

